@@ -597,7 +597,7 @@ const static gchar hex[16]={'0', '1', '2', '3', '4', '5', '6', '7',
 /*  ja:数値→文字列
     value,数値
     radix,基数
-     wide,桁数
+     wide,桁数(正:空白,負:0)
      flag,TRUE:符号あり,FALSE:符号なし
       RET,文字列                                                            */
 gchar *
@@ -606,8 +606,8 @@ misc_str_from_val (const gint     value,
                    const gint     wide,
                    const gboolean flag)
 {
-  gchar c, *str = NULL;
-  gint i = 0, j, t;
+  gchar *str = NULL;
+  gint i = 0, t;
 
   t = value;
   if (value == 0)
@@ -638,14 +638,11 @@ misc_str_from_val (const gint     value,
     }
   str = g_realloc (str, (i + 1) * sizeof (gchar));
   str[i] = '\0';
-  for (j = 0; j < i / 2; j++)
-    {
-      c = str[j];
-      str[j] = str[i - j - 1];
-      str[i - j - 1] = c;
-    }
+  g_strreverse (str);
   if (flag && value < 0)
     {
+      gint j;
+
       for (j = i; j >= 0; j--)
         str[j + 1] = str[j];
       str[0] = '-';
@@ -653,6 +650,8 @@ misc_str_from_val (const gint     value,
     }
   if (i < ABS (wide))
     {
+      gint j;
+
       str = g_realloc (str, (ABS (wide) + 1) * sizeof (gchar));
       for (j = i; j >= 0; j--)
         str[j + ABS (wide) - i] = str[j];
@@ -879,7 +878,7 @@ misc_str_to_float (gint        *value,
      size,要素数
      bits,ビット数
     radix,基数
-     wide,桁数
+     wide,桁数(正:空白,負:0)
      flag,TRUE:符号あり,FALSE:符号なし
       RET,文字列                                                            */
 gchar *
