@@ -1,6 +1,6 @@
 /*
     misc
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -187,7 +187,7 @@ misc_dialog_key_press (GtkWidget   *widget,
 /*  ja:数値→文字列
     value,数値
     radix,基数
-     wide,桁数
+     wide,桁数(正:空白,負:0)
      flag,TRUE:符号あり,FALSE:符号なし
       RET,文字列                                                            */
 gchar *
@@ -235,7 +235,7 @@ misc_str_to_float (gint        *value,
      size,要素数
      bits,ビット数
     radix,基数
-     wide,桁数
+     wide,桁数(正:空白,負:0)
      flag,TRUE:符号あり,FALSE:符号なし
       RET,文字列                                                            */
 gchar *
