@@ -1,6 +1,6 @@
 /*
     orzmdi
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -113,7 +113,7 @@ file_add_edit (OrzMdi    *mdi,
 
   tab0->same = -2;
   /* ja:ファイル名を調べる */
-  glist = gtk_container_children (GTK_CONTAINER (mdi));
+  glist = gtk_container_get_children (GTK_CONTAINER (mdi));
   /* ja:同名同パスを調べる */
   for (i = g_list_length (glist) - 1; i >= 0; i--)
     {
@@ -178,7 +178,7 @@ file_remove_edit (OrzMdi      *mdi,
   OrzMdiTab *tab1;
 
   /* ja:ファイル名を調べる */
-  glist = gtk_container_children (GTK_CONTAINER (mdi));
+  glist = gtk_container_get_children (GTK_CONTAINER (mdi));
   name0 = g_path_get_basename (tab0->file);
   for (i = g_list_length (glist) - 1; i >= 0; i--)
     {
@@ -260,7 +260,7 @@ orz_mdi_get_type (void)
         NULL,               /* class_finalize */
         NULL,               /* class_data */
         sizeof (OrzMdi),
-        0,              /* n_preallocs */
+        0,                  /* n_preallocs */
         (GInstanceInitFunc)orz_mdi_init,
       };
 
@@ -293,9 +293,6 @@ orz_mdi_remove (GtkContainer *container,
                     gtk_notebook_page_num (GTK_NOTEBOOK (container), widget),
                     tab->page_data);
           file_remove_edit (ORZ_MDI (container), tab, NULL);
-          g_free (tab->file);
-          g_free (tab);
-          g_object_set_data (G_OBJECT (tab_label), "user_data", NULL);
         }
     }
   ((GtkContainerClass *)parent_class)->remove (container, widget);
@@ -335,26 +332,26 @@ orz_mdi_switch_page (GtkNotebook     *notebook,
 static void
 orz_mdi_class_init (OrzMdiClass *klass)
 {
-  GObjectClass *gobject_class;
-  GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
   GtkContainerClass *container_class;
   GtkNotebookClass *notebook_class;
 
-  gobject_class = (GObjectClass *) klass;
-  object_class = (GtkObjectClass *) klass;
-  widget_class = (GtkWidgetClass *) klass;
   container_class = (GtkContainerClass *) klass;
   notebook_class = (GtkNotebookClass *) klass;
 
   parent_class = g_type_class_peek_parent (klass);
-
   container_class->remove = orz_mdi_remove;
   notebook_class->switch_page = orz_mdi_switch_page;
 
+  klass->add_window = NULL;
+  klass->change_window = NULL;
+  klass->close_window = NULL;
+  klass->remove_window = NULL;
+  klass->reorder_window = NULL;
+  klass->switch_window = NULL;
+
   orz_mdi_signals[ADD_WINDOW_SIGNAL]
                 = g_signal_new ("add_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, add_window),
                                 NULL, NULL,
@@ -364,7 +361,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[CHANGE_WINDOW_SIGNAL]
                 = g_signal_new ("change_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, change_window),
                                 NULL, NULL,
@@ -374,7 +371,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[CLOSE_WINDOW_SIGNAL]
                 = g_signal_new ("close_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, close_window),
                                 NULL, NULL,
@@ -384,7 +381,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[REMOVE_WINDOW_SIGNAL]
                 = g_signal_new ("remove_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, remove_window),
                                 NULL, NULL,
@@ -394,7 +391,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[REORDER_WINDOW_SIGNAL]
                 = g_signal_new ("reorder_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, reorder_window),
                                 NULL, NULL,
@@ -404,7 +401,7 @@ orz_mdi_class_init (OrzMdiClass *klass)
                                 G_TYPE_POINTER);
   orz_mdi_signals[SWITCH_WINDOW_SIGNAL]
                 = g_signal_new ("switch_window",
-                                G_TYPE_FROM_CLASS (gobject_class),
+                                G_TYPE_FROM_CLASS (klass),
                                 G_SIGNAL_RUN_LAST,
                                 G_STRUCT_OFFSET (OrzMdiClass, switch_window),
                                 NULL, NULL,
@@ -455,8 +452,8 @@ orz_mdi_clicked (GtkWidget *widget,
 
 /* ja:子ウィジェットが破棄されるとき */
 static void
-orz_mdi_destroy (GtkWidget *widget,
-                 OrzMdi    *mdi)
+orz_mdi_destroy_child (GtkWidget *widget,
+                       OrzMdi    *mdi)
 {
   GtkWidget *tab_label;
 
@@ -474,14 +471,28 @@ orz_mdi_destroy (GtkWidget *widget,
                          gtk_notebook_page_num (GTK_NOTEBOOK (mdi), widget),
                          tab->page_data);
           file_remove_edit (ORZ_MDI (mdi), tab, NULL);
-          g_free (tab->file);
-          g_free (tab);
-          g_object_set_data (G_OBJECT (tab_label), "user_data", NULL);
         }
     }
 }
 
 
+/* ja:タブが破棄されるとき */
+static void
+orz_mdi_destroy_tab (GtkWidget *widget,
+                     OrzMdi    *mdi)
+{
+  OrzMdiTab *tab;
+
+  tab = g_object_get_data (G_OBJECT (widget), "user_data");
+  if (tab)
+    {
+      g_free (tab->file);
+      g_free (tab);
+      g_object_set_data (G_OBJECT (widget), "user_data", NULL);
+    }
+}
+
+
 /* ja:ドロップされたとき */
 static void
 orz_mdi_tab_drag_begin (GtkWidget      *widget,
@@ -492,7 +503,7 @@ orz_mdi_tab_drag_begin (GtkWidget      *widget,
   OrzMdiTab *tab;
 
   tab = g_object_get_data (G_OBJECT (widget), "user_data");
-  pixbuf = fileio_extract_icon (tab->file, FILEIO_ICON_SIZE_LARGE);
+  pixbuf = fileio_extract_icon (tab->file, GTK_ICON_SIZE_DND);
   if (pixbuf)
     {
       gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
@@ -583,7 +594,7 @@ orz_mdi_create_tab_label (OrzMdi         *mdi,
                                          gtk_widget_get_default_style (),
                                          GTK_TEXT_DIR_NONE,
                                          GTK_STATE_NORMAL,
-                                         GTK_ICON_SIZE_BUTTON,
+                                         GTK_ICON_SIZE_MENU,
                                          NULL, NULL);
       if (pixbuf)
         {
@@ -645,7 +656,7 @@ orz_mdi_create_tab_label (OrzMdi         *mdi,
         }
     }
   if (!image)
-    image = gtk_image_new_from_stock (GTK_STOCK_CDROM, GTK_ICON_SIZE_BUTTON);
+    image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
   if (!image)
     {
       const static gchar *xpm[] = {
@@ -682,7 +693,7 @@ orz_mdi_create_tab_label (OrzMdi         *mdi,
   orz_mdi_label_markup (tab);
   gtk_widget_show (tab->label);
   /* ja:アイコン */
-  pixbuf = fileio_extract_icon (tab->file, FILEIO_ICON_SIZE_SMALL);
+  pixbuf = fileio_extract_icon (tab->file, GTK_ICON_SIZE_BUTTON);
   if (pixbuf)
     {
       tab->image = gtk_image_new_from_pixbuf (pixbuf);
@@ -703,9 +714,11 @@ orz_mdi_create_tab_label (OrzMdi         *mdi,
   g_object_set_data (G_OBJECT (event), "user_data", tab);
 
   g_signal_connect (G_OBJECT (button), "clicked",
-                                        G_CALLBACK (orz_mdi_clicked), event);
+                                    G_CALLBACK (orz_mdi_clicked), event);
   g_signal_connect (G_OBJECT (child), "destroy",
-                                        G_CALLBACK (orz_mdi_destroy), mdi);
+                                    G_CALLBACK (orz_mdi_destroy_child), mdi);
+  g_signal_connect (G_OBJECT (event), "destroy",
+                                    G_CALLBACK (orz_mdi_destroy_tab), mdi);
   /* en:Drag & Drop */
   gtk_drag_source_set (event, GDK_BUTTON1_MASK, dnd_entries, 1,
                                                             GDK_ACTION_MOVE);
@@ -874,7 +887,7 @@ orz_mdi_get_n_pages (OrzMdi *mdi)
     {
       GList *glist;
 
-      glist = gtk_container_children (GTK_CONTAINER (mdi));
+      glist = gtk_container_get_children (GTK_CONTAINER (mdi));
       if (glist)
         {
           n_pages = g_list_length (glist);
@@ -925,8 +938,8 @@ orz_mdi_get_tab (OrzMdi     *mdi,
           GtkWidget *tab_label;
 
           tab_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (mdi), child);
-          if (tab_label)
-            return g_object_get_data (G_OBJECT (tab_label), "user_data");
+          if (tab_label){
+            return g_object_get_data (G_OBJECT (tab_label), "user_data");}
         }
     }
   return NULL;
@@ -1033,7 +1046,7 @@ orz_mdi_set_file (OrzMdi      *mdi,
                     gtk_container_remove (GTK_CONTAINER (hbox), tab->image);
                   tab->image = NULL;
                   pixbuf = fileio_extract_icon (tab->file,
-                                                    FILEIO_ICON_SIZE_SMALL);
+                                                        GTK_ICON_SIZE_BUTTON);
                   if (pixbuf)
                     {
                       tab->image = gtk_image_new_from_pixbuf (pixbuf);
